@@ -66,8 +66,8 @@ winProbabilityLR <- function(match,t1,t2,plot=1){
     team1Size=0
     requiredRuns=0
 
-
-    teamA=match$team[grep("1st.0.1",match$ball)]
+    teams=unique(match$team)
+    teamA=teams[1]
 
     # Filter the performance of team1
     a <-filter(match,team==teamA)
@@ -115,7 +115,7 @@ winProbabilityLR <- function(match,t1,t2,plot=1){
 
     # Required runs is the team made by team 1 + 1
     requiredRuns=d[dim(d)[1],]$runs +1
-    teamB=match$team[grep("2nd.0.1",match$ball)]
+    teamB=teams[2]
 
 
     # Filter the performance of team1
